<?php
/**
 * EightMedi Pro Theme Customizer Custom
 *
 * @package EightMedi Pro
 */

/**
 * Add new options the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function eightmedi_pro_custom_customize_register_homepage( $wp_customize ) {
	
	//Adding the Homepage Setup Panel
	$wp_customize->add_panel('eightmedi_pro_homepage_setups',array(
		'priority' => '30',
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => __('Homepage Setups','eightmedi-pro'),		
	));

	//Sorting section
	$wp_customize->add_section(
		'eightmedi_pro_homepage_setting_sorting_section',
		array(
			'title'         =>  __('Sorting Homepage Section','eightmedi-pro'),
			'description'   =>  __('You can reorder the section of the homepage.','eightmedi-pro'),
			'priority'      =>  05,
			'panel'         =>	'eightmedi_pro_homepage_setups',
		)
	);

	// Section Reorder Control
	$wp_customize->add_setting( 
		'eightmedi_pro_homepage_setting_sorting_section_orders', 
		array( 
			'default' 	=> 'slider,homecontent,featured,appointment,aboutus,teammember,callto,news,testimonial,faqs,widgetone,sponsors,ctasmall,contact,',
			'sanitize_callback' => 'sanitize_text_field' 
		)
	);

	$wp_customize->add_control( 
		new Eightmedi_Pro_Section_ReOrder( 
			$wp_customize, 
			'eightmedi_pro_homepage_setting_sorting_section_orders',
			array(
				'label' => __( 'Reorder Homepage Section', 'eightmedi-pro' ),
				'section' => 'eightmedi_pro_homepage_setting_sorting_section',
				'description' => __('Drag and drop to reorder Homepage sections.', 'eightmedi-pro'),
				'settings' => 'eightmedi_pro_homepage_setting_sorting_section_orders',
				'choices' => array(
					'slider' => __('Slider Section','eightmedi-pro'),
					'homecontent' => __('Page Content','eightmedi-pro'),
					'featured' => __('Featured Section', 'eightmedi-pro'),
					'appointment' => __('Book An Appointment Section', 'eightmedi-pro'),
					'aboutus' => __('About Section', 'eightmedi-pro'),
					'teammember' => __('Team Member Section', 'eightmedi-pro'),
					'callto' => __('Call To Action Section', 'eightmedi-pro'),
					'news' => __('Latest News Section', 'eightmedi-pro'),
					'testimonial' => __('Testimonial Section', 'eightmedi-pro'),
					'faqs' => __('FAQs Section', 'eightmedi-pro'),
					'widgetone' => __('Widget Area Section', 'eightmedi-pro'),
					'sponsors' => __('Sponsors Section', 'eightmedi-pro'),
					'ctasmall' => __('Small CTA section', 'eightmedi-pro'),
					'contact' => __('Google Map Section', 'eightmedi-pro'),
				),
			)
		)
	);
	
	//Adding the Slider Setup Panel
	$wp_customize->add_section('eightmedi_pro_slider_setups',array(
		'priority' => '10',
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => __('Slider Setups','eightmedi-pro'),
		'description' => __('Manage Slides for the site','eightmedi-pro'),
		'panel' => 'eightmedi_pro_homepage_setups'
	));

	$wp_customize->add_setting('eightmedi_pro_display_slider', array(
		'default' => '1',
		'sanitize_callback' => 'eightmedi_pro_sanitize_radio_integer'
	));

	$wp_customize->add_control('eightmedi_pro_display_slider',array(
		'type' => 'radio',
		'label' => __('Display Slider', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_slider_setups',
		'choices' => array(
			'1' => __('Yes','eightmedi-pro'),
			'0' => __('No','eightmedi-pro')
		)
	));

	//Slider Type
	$wp_customize->add_setting('eightmedi_pro_slider_type', array(
		'default' => 'category',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_slidertype',
	));

	$wp_customize->add_control('eightmedi_pro_slider_type', array(
		'type' => 'radio',
		'label' => __('Select Slider Type', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_slider_setups',
		'choices' => array(
			'revolution' => __('Revolution', 'eightmedi-pro'),
			'category' => __('Category', 'eightmedi-pro'),
		)
	));

	//slider shortcode
	$wp_customize->add_setting('eightmedi_pro_slider_shortcode', array(
		'default' => '',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
	));

	$wp_customize->add_control('eightmedi_pro_slider_shortcode',array(
		'type' => 'text',
		'label' => __('Revolution Slider/Other Plugin Slider Shortcode','eightmedi-pro'),
		'section' => 'eightmedi_pro_slider_setups',
		'active_callback' => 'eightmedi_pro_flag_slider_type_revolution',
	));

   	//select category for slider
	$wp_customize->add_setting('eightmedi_pro_slider_category',array(
		'default' => '',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'absint'
	));

	$wp_customize->add_control( new eightmedi_pro_WP_Customize_Category_Control( $wp_customize,'eightmedi_pro_slider_category', array(
		'label' => __('Select a category to show in slider','eightmedi-pro'),
		'section' => 'eightmedi_pro_slider_setups',
		'active_callback' => 'eightmedi_pro_flag_slider_type_category',
	)));

	//slider pager
	$wp_customize->add_setting('eightmedi_pro_display_pager', array(
		'default' => '1',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_sanitize_radio_integer',
	));

	$wp_customize->add_control('eightmedi_pro_display_pager',array(
		'type' => 'radio',
		'label' => __('Display Pager', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_slider_setups',
		'choices' => array(
			'1' => __('Yes','eightmedi-pro'),
			'0' => __('No','eightmedi-pro')
		),
		'active_callback' => 'eightmedi_pro_flag_slider_type_category',
	));
	//slider controls
	$wp_customize->add_setting('eightmedi_pro_display_controls', array(
		'default' => '1',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_sanitize_radio_integer',
	));

	$wp_customize->add_control('eightmedi_pro_display_controls',array(
		'type' => 'radio',
		'label' => __('Display Controls', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_slider_setups',
		'choices' => array(
			'1' => __('Yes','eightmedi-pro'),
			'0' => __('No','eightmedi-pro')
		),
		'active_callback' => 'eightmedi_pro_flag_slider_type_category',
	));
	//slider auto transition
	$wp_customize->add_setting('eightmedi_pro_auto_transition', array(
		'default' => '1',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_sanitize_radio_integer',
	));

	$wp_customize->add_control('eightmedi_pro_auto_transition',array(
		'type' => 'radio',
		'label' => __('Enable Auto Transition', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_slider_setups',
		'choices' => array(
			'1' => __('Yes','eightmedi-pro'),
			'0' => __('No','eightmedi-pro')
		),
		'active_callback' => 'eightmedi_pro_flag_slider_type_category',
	));
	//slider transitiontype
	$wp_customize->add_setting('eightmedi_pro_transition_type', array(
		'default' => '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_sanitize_radio_integer',
	));

	$wp_customize->add_control('eightmedi_pro_transition_type',array(
		'type' => 'radio',
		'label' => __('Transition Type', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_slider_setups',
		'choices' => array(
			'1' => __('Slide','eightmedi-pro'),
			'0' => __('Fade','eightmedi-pro')
		),
		'active_callback' => 'eightmedi_pro_flag_slider_type_category',
	));
	//slider caption
	$wp_customize->add_setting('eightmedi_pro_slider_text', array(
		'default' => '1',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_sanitize_radio_integer',
	));

	$wp_customize->add_control('eightmedi_pro_slider_text',array(
		'type' => 'radio',
		'label' => __('Display Text in Slider', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_slider_setups',
		'choices' => array(
			'1' => __('Yes','eightmedi-pro'),
			'0' => __('No','eightmedi-pro')
		),
		'active_callback' => 'eightmedi_pro_flag_slider_type_category',
	));

	//slider transition speed
	$wp_customize->add_setting('eightmedi_pro_transition_speed', array(
		'default' => '2000',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('eightmedi_pro_transition_speed',array(
		'type' => 'number',
		'label' => __('Transition Speed', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_slider_setups',
		'active_callback' => 'eightmedi_pro_flag_slider_type_category',
	));
	//slider transition pause
	$wp_customize->add_setting('eightmedi_pro_transition_pause', array(
		'default' => '5000',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('eightmedi_pro_transition_pause',array(
		'type' => 'number',
		'label' => __('Slide Pause Time', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_slider_setups',
		'active_callback' => 'eightmedi_pro_flag_slider_type_category',
	));

	$wp_customize->add_setting('slider_add_links_on_image_title',array(
		'default' => '1',
	));
	$wp_customize->add_control('slider_add_links_on_image_title',array(
		'type' => 'radio',
		'label' => __('Add link to post on Slider Image and title', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_slider_setups',
		'choices' => array('1' => __('Yes','eightmedi-pro'),
			'0' => __('No','eightmedi-pro')),
		'active_callback' => 'eightmedi_pro_flag_slider_type_category',
	));


	//slider bottom cta button
	$wp_customize->add_setting('eightmedi_pro_slider_cta_btntext', array(
		'default' => '',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
	));

	$wp_customize->add_control('eightmedi_pro_slider_cta_btntext',array(
		'type' => 'text',
		'label' => __('Slider CTA Button Text', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_slider_setups',
	));

	//slider bottom cta button link
	$wp_customize->add_setting('eightmedi_pro_slider_cta_btnlink', array(
		'default' => '#book-an-appointment',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
	));

	$wp_customize->add_control('eightmedi_pro_slider_cta_btnlink',array(
		'type' => 'text',
		'label' => __('Slider CTA Button Link', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_slider_setups',
	));

	$wp_customize->add_setting('eightmedi_pro_slider_cta_btn_color', array(
		'default' => '#cc444d',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_hex_color',
	));

	$wp_customize->add_control( new WP_Customize_Color_Control($wp_customize , 'eightmedi_pro_slider_cta_btn_color',array(
		'label' => __('Choose Button Background Color.','eightmedi-pro'),
		'section' => 'eightmedi_pro_slider_setups',
	)));


	//featured Section
	$wp_customize->add_section('eightmedi_pro_featured_section', array(
		'priority' => 60,
		'title' => __('Featured Section', 'eightmedi-pro'),
		'description' => __('Featured Section posts will be loaded from post type Services', 'eightmedi-pro'),
		'panel' => 'eightmedi_pro_homepage_setups',
	));

    //enable disable featured section
	$wp_customize->add_setting('eightmedi_pro_featured_setting_option', array(
		'default' => 'disable',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_enabledisable',
	));

	$wp_customize->add_control('eightmedi_pro_featured_setting_option', array(
		'type' => 'radio',
		'label' => __('Enable Disable Featured Section', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_featured_section',
		'setting' => 'eightmedi_pro_featured_setting_option',
		'choices' => array(
			'enable' => __('Enable', 'eightmedi-pro'),
			'disable' => __('Disable', 'eightmedi-pro'),
		)
	));

   //featured Title
	$wp_customize->add_setting('eightmedi_pro_featured_title', array(
		'default' => '',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
	));

	$wp_customize->add_control('eightmedi_pro_featured_title',array(
		'type' => 'text',
		'label' => __('Latest featured Title','eightmedi-pro'),
		'section' => 'eightmedi_pro_featured_section',
		'setting' => 'eightmedi_pro_featured_title'
	));

	$wp_customize->add_setting('eightmedi_pro_featured_customlink_opt', array(
		'default' => 'disable',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_enabledisable',
	));

	$wp_customize->add_control('eightmedi_pro_featured_customlink_opt', array(
		'type' => 'radio',
		'label' => __('Enable Custom Link of Post in Featured Section', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_featured_section',
		'setting' => 'eightmedi_pro_featured_customlink_opt',
		'choices' => array(
			'enable' => __('Enable', 'eightmedi-pro'),
			'disable' => __('Disable', 'eightmedi-pro'),
		)
	));
	$wp_customize->add_setting('eightmedi_pro_featured_imgicon', array(
		'default' => 'icon',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_imgicon',
	));

	$wp_customize->add_control('eightmedi_pro_featured_imgicon', array(
		'type' => 'radio',
		'label' => __('Priority for Image or Icon', 'eightmedi-pro'),
		'description' => __('If image is choosen as priority, then image will be loaded if both image and icon are available and vice-versa', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_featured_section',
		'setting' => 'eightmedi_pro_featured_imgicon',
		'choices' => array(
			'icon' => __('Icon', 'eightmedi-pro'),
			'image' => __('Image', 'eightmedi-pro'),
		)
	));

	//featured number
	$wp_customize->add_setting('eightmedi_pro_featured_number_posts', array(
		'default' => '5',
		'sanitize_callback' => 'eightmedi_pro_floatval',
	));

	$wp_customize->add_control('eightmedi_pro_featured_number_posts',array(
		'type' => 'number',
		'label' => __('Number of Posts','eightmedi-pro'),
		'description' => __('Better choose in multiple of 5 to adjust with design properly like 10,15,20','eightmedi-pro'),
		'section' => 'eightmedi_pro_featured_section',
		'setting' => 'eightmedi_pro_featured_number_posts'
	));
	

	//here goes book an appointment
	$wp_customize->add_section('eightmedi_pro_appointment_section', array(
		'priority' => 60,
		'title' => __('Book an Appointment Section', 'eightmedi-pro'),
		'panel' => 'eightmedi_pro_homepage_setups',
	));

    //enable disable Book an Appointment section
	$wp_customize->add_setting('eightmedi_pro_appointment_setting_option', array(
		'default' => 'disable',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_enabledisable',
	));

	$wp_customize->add_control('eightmedi_pro_appointment_setting_option', array(
		'type' => 'radio',
		'label' => __('Enable Disable Book an Appointment', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_appointment_section',
		'setting' => 'eightmedi_pro_appointment_setting_option',
		'choices' => array(
			'enable' => __('Enable', 'eightmedi-pro'),
			'disable' => __('Disable', 'eightmedi-pro'),
		)
	));


   //Book an Appointment Title
	$wp_customize->add_setting('eightmedi_pro_appointment_title', array(
		'default' => 'Book An Appointment',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
		'transport' => 'postMessage'
	));

	$wp_customize->add_control('eightmedi_pro_appointment_title',array(
		'type' => 'text',
		'label' => __('Book an Appointment Title','eightmedi-pro'),
		'section' => 'eightmedi_pro_appointment_section',
		'setting' => 'eightmedi_pro_appointment_title'
	));

    //Book an Appointment section description
	$wp_customize->add_setting('eightmedi_pro_appointment_desc', array(
		'default' => '',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
	));

	$wp_customize->add_control('eightmedi_pro_appointment_desc',array(
		'type' => 'textarea',
		'label' => __('Book an Appointment Description','eightmedi-pro'),
		'section' => 'eightmedi_pro_appointment_section',
		'setting' => 'eightmedi_pro_appointment_desc'
	));

    //Book an Appointment link
	$wp_customize->add_setting('eightmedi_pro_appointment_formid', array(
		'default' => '',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
	));

	$wp_customize->add_control('eightmedi_pro_appointment_formid',array(
		'type' => 'text',
		'label' => __('Book an Appointment Custom Form Id','eightmedi-pro'),
		'description' => __('Enter shortcode for Custom Form Id','eightmedi-pro'),
		'section' => 'eightmedi_pro_appointment_section', 
		'setting' => 'eightmedi_pro_appointment_formid'
	));

	//form alignment
	$wp_customize->add_setting('eightmedi_pro_appointment_form_align', array(
		'default' => 'left',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_align',
	));

	$wp_customize->add_control('eightmedi_pro_appointment_form_align', array(
		'type' => 'radio',
		'label' => __('Choose alignment of form', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_appointment_section',
		'setting' => 'eightmedi_pro_appointment_setting_option',
		'choices' => array(
			'left' => __('Left', 'eightmedi-pro'),
			'center' => __('Center', 'eightmedi-pro'),
			'right' => __('Right', 'eightmedi-pro'),
		)
	));

   //Book an Appointment background image
	$wp_customize->add_setting('eightmedi_pro_appointment_bkgimage', array(
		'default' => '',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'esc_url_raw'
	));

	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'eightmedi_pro_appointment_bkgimage', array(
		'label' => __('Background Image for Book an Appointment', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_appointment_section',
		'setting' => 'eightmedi_pro_appointment_bkgimage'
	)));

	//homepage about us section
	$wp_customize->add_section('eightmedi_pro_about_section', array(
		'priority' => 60,
		'title' => __('About Section', 'eightmedi-pro'),
		'panel' => 'eightmedi_pro_homepage_setups',
	));

    //enable disable about us section
	$wp_customize->add_setting('eightmedi_pro_about_setting_option', array(
		'default' => 'disable',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_enabledisable',
	));

	$wp_customize->add_control('eightmedi_pro_about_setting_option', array(
		'type' => 'radio',
		'label' => __('Enable Disable About Us Section', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_about_section',
		'setting' => 'eightmedi_pro_about_setting_option',
		'choices' => array(
			'enable' => __('Enable', 'eightmedi-pro'),
			'disable' => __('Disable', 'eightmedi-pro'),
		)
	));

	$options_posts = array();
	$options_posts_obj = get_posts('posts_per_page=-1');
	$options_posts[''] = 'Select a Post:';
	foreach ($options_posts_obj as $post) {
		$options_posts[$post->ID] = $post->post_title;
	}
   //select post for about us
	$wp_customize->add_setting('eightmedi_pro_about_setting_post',array(
		'default' => '',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'absint'
	));

	$wp_customize->add_control('eightmedi_pro_about_setting_post', array(
		'type' => 'select',
		'label' => __('Select a Post to show in About Us Section','eightmedi-pro'),
		'section' => 'eightmedi_pro_about_section',
		'setting' => 'eightmedi_pro_about_setting_option',
		'choices' => $options_posts
	));

   //about us view more text
	$wp_customize->add_setting('eightmedi_pro_aboutus_viewmore_text', array(
		'default' => 'Details',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
		'transport' => 'postMessage'
	));

	$wp_customize->add_control('eightmedi_pro_aboutus_viewmore_text',array(
		'type' => 'text',
		'label' => __('About View More Text','eightmedi-pro'),
		'section' => 'eightmedi_pro_about_section',
		'setting' => 'eightmedi_pro_aboutus_viewmore_text'
	));

	//about alignment
	$wp_customize->add_setting('eightmedi_pro_aboutus_align', array(
		'default' => 'left',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_align',
	));

	$wp_customize->add_control('eightmedi_pro_aboutus_align', array(
		'type' => 'radio',
		'label' => __('Choose alignment of Image', 'eightmedi-pro'),
		'description' => __('Centre alignment will make image as background', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_about_section',
		'setting' => 'eightmedi_pro_aboutus_align',
		'choices' => array(
			'left' => __('Left', 'eightmedi-pro'),
			'center' => __('Center', 'eightmedi-pro'),
			'right' => __('Right', 'eightmedi-pro'),
		)
	));

	//Team Member Section
	$wp_customize->add_section('eightmedi_pro_teammember_section', array(
		'priority' => 70,
		'title' => __('Team Member Section', 'eightmedi-pro'),
		'description' => __('Team Section posts will be loaded from post type Doctor', 'eightmedi-pro'),
		'panel' => 'eightmedi_pro_homepage_setups',
	));

    //enable disable teammember section
	$wp_customize->add_setting('eightmedi_pro_teammember_setting_option', array(
		'default' => 'disable',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_enabledisable',
	));

	$wp_customize->add_control('eightmedi_pro_teammember_setting_option', array(
		'type' => 'radio',
		'label' => __('Enable Disable Team Member', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_teammember_section',
		'setting' => 'eightmedi_pro_teammember_setting_option',
		'choices' => array(
			'enable' => __('Enable', 'eightmedi-pro'),
			'disable' => __('Disable', 'eightmedi-pro'),
		)
	));


   //Team member Title
	$wp_customize->add_setting('eightmedi_pro_teammember_title', array(
		'default' => 'Team Member',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
	));

	$wp_customize->add_control('eightmedi_pro_teammember_title',array(
		'type' => 'text',
		'label' => __('Team Memeber Title','eightmedi-pro'),
		'section' => 'eightmedi_pro_teammember_section',
		'setting' => 'eightmedi_pro_teammember_title'
	));

	//Team member Desc
	$wp_customize->add_setting('eightmedi_pro_teammember_desc', array(
		'default' => '',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
	));

	$wp_customize->add_control('eightmedi_pro_teammember_desc',array(
		'type' => 'textarea',
		'label' => __('Team Memeber Description','eightmedi-pro'),
		'section' => 'eightmedi_pro_teammember_section',
		'setting' => 'eightmedi_pro_teammember_desc'
	));

	//about alignment
	$wp_customize->add_setting('eightmedi_pro_teammember_layout', array(
		'default' => 'halfwidth',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_fullhalf',
	));

	$wp_customize->add_control('eightmedi_pro_teammember_layout', array(
		'type' => 'radio',
		'label' => __('Choose Team Member Layout', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_teammember_section',
		'setting' => 'eightmedi_pro_teammember_layout',
		'choices' => array(
			'halfwidth' => __('Half Half', 'eightmedi-pro'),
			'fullwidth' => __('Fullwidth', 'eightmedi-pro'),
		)
	));

   //Team Member button enable disable
	$wp_customize->add_setting('eightmedi_pro_teammember_button_option', array(
		'default' => 'disable',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_enabledisable',
	));

	$wp_customize->add_control('eightmedi_pro_teammember_button_option', array(
		'type' => 'radio',
		'label' => __('Display Button for Category Page', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_teammember_section',
		'setting' => 'eightmedi_pro_teammember_button_option',
		'choices' => array(
			'enable' => __('Enable', 'eightmedi-pro'),
			'disable' => __('Disable', 'eightmedi-pro'),
		)
	));

   //Team Member Button View more text
	$wp_customize->add_setting('eightmedi_pro_teammember_button_text', array(
		'default' => 'View More',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
		'transport' => 'postMessage'
	));

	$wp_customize->add_control('eightmedi_pro_teammember_button_text',array(
		'type' => 'text',
		'label' => __('Button Text','eightmedi-pro'),
		'section' => 'eightmedi_pro_teammember_section',
		'setting' => 'eightmedi_pro_teammember_button_text'
	));


	//Call To Action Section

	$wp_customize->add_section('eightmedi_pro_callto_section', array(
		'priority' => 70,
		'title' => __('Call To Action Section', 'eightmedi-pro'),
		'panel' => 'eightmedi_pro_homepage_setups',
	));

    //enable disable call to action section
	$wp_customize->add_setting('eightmedi_pro_callto_setting_option', array(
		'default' => 'disable',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_enabledisable',
	));

	$wp_customize->add_control('eightmedi_pro_callto_setting_option', array(
		'type' => 'radio',
		'label' => __('Enable Disable Call To Action', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_callto_section',
		'setting' => 'eightmedi_pro_callto_setting_option',
		'choices' => array(
			'enable' => __('Enable', 'eightmedi-pro'),
			'disable' => __('Disable', 'eightmedi-pro'),
		)
	));


   //call to action Title
	$wp_customize->add_setting('eightmedi_pro_callto_title', array(
		'default' => 'EightMedi Pro',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
		'transport' => 'postMessage'
	));

	$wp_customize->add_control('eightmedi_pro_callto_title',array(
		'type' => 'text',
		'label' => __('Call To Action Title','eightmedi-pro'),
		'section' => 'eightmedi_pro_callto_section',
		'setting' => 'eightmedi_pro_callto_title'
	));

    //call to section description
	$wp_customize->add_setting('eightmedi_pro_callto_desc', array(
		'default' => '',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
		'transport' => 'postMessage'
	));

	$wp_customize->add_control('eightmedi_pro_callto_desc',array(
		'type' => 'textarea',
		'label' => __('Call To Description','eightmedi-pro'),
		'section' => 'eightmedi_pro_callto_section',
		'setting' => 'eightmedi_pro_callto_desc'
	));

    //call to action read more
	$wp_customize->add_setting('eightmedi_pro_callto_readmore', array(
		'default' => 'Join',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
		'transport' => 'postMessage'
	));

	$wp_customize->add_control('eightmedi_pro_callto_readmore',array(
		'type' => 'text',
		'label' => __('Call To Action Read More Text','eightmedi-pro'),
		'section' => 'eightmedi_pro_callto_section',
		'setting' => 'eightmedi_pro_callto_readmore'
	));

   //call to action link
	$wp_customize->add_setting('eightmedi_pro_callto_link', array(
		'default' => '',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',

	));

	$wp_customize->add_control('eightmedi_pro_callto_link',array(
		'type' => 'text',
		'label' => __('Call To Action Link','eightmedi-pro'),
		'section' => 'eightmedi_pro_callto_section',
		'setting' => 'eightmedi_pro_callto_link'
	));

	$wp_customize->add_setting('eightmedi_pro_callto_align', array(
		'default' => 'left',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_align',
	));

	$wp_customize->add_control('eightmedi_pro_callto_align', array(
		'type' => 'radio',
		'label' => __('Choose alignment of Call To Section', 'eightmedi-pro'),
		'description' => __('Centre alignment will make image as background', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_callto_section',
		'setting' => 'eightmedi_pro_callto_align',
		'choices' => array(
			'left' => __('Left', 'eightmedi-pro'),
			'center' => __('Center', 'eightmedi-pro'),
			'right' => __('Right', 'eightmedi-pro'),
		)
	));

   //call to action background image
	$wp_customize->add_setting('eightmedi_pro_callto_bkgimage', array(
		'default' => '',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'esc_url_raw'
	));

	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'eightmedi_pro_callto_bkgimage', array(
		'label' => __('Image for Call to Action', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_callto_section',
		'setting' => 'eightmedi_pro_callto_bkgimage'
	)));

	//latest news Section
	$wp_customize->add_section('eightmedi_pro_news_section', array(
		'priority' => 70,
		'title' => __('Latest News Section', 'eightmedi-pro'),
		'panel' => 'eightmedi_pro_homepage_setups',
	));

    //enable disable news section
	$wp_customize->add_setting('eightmedi_pro_news_setting_option', array(
		'default' => 'disable',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_enabledisable',
	));

	$wp_customize->add_control('eightmedi_pro_news_setting_option', array(
		'type' => 'radio',
		'label' => __('Enable Disable News Section', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_news_section',
		'setting' => 'eightmedi_pro_news_setting_option',
		'choices' => array(
			'enable' => __('Enable', 'eightmedi-pro'),
			'disable' => __('Disable', 'eightmedi-pro'),
		)
	));


   //News Title
	$wp_customize->add_setting('eightmedi_pro_news_title', array(
		'default' => 'Our Journal',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
	));

	$wp_customize->add_control('eightmedi_pro_news_title',array(
		'type' => 'text',
		'label' => __('News Section','eightmedi-pro'),
		'section' => 'eightmedi_pro_news_section',
		'setting' => 'eightmedi_pro_news_title'
	));

	//News Desc
	$wp_customize->add_setting('eightmedi_pro_news_desc', array(
		'default' => '',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
	));

	$wp_customize->add_control('eightmedi_pro_news_desc',array(
		'type' => 'textarea',
		'label' => __('News Section Description','eightmedi-pro'),
		'section' => 'eightmedi_pro_news_section',
		'setting' => 'eightmedi_pro_news_desc'
	));

     //select category for news
	$wp_customize->add_setting('eightmedi_pro_news_setting_category',array(
		'default' => '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'absint'
	));

	$wp_customize->add_control( new eightmedi_pro_WP_Customize_Category_Control( $wp_customize,'eightmedi_pro_news_setting_category', array(
		'label' => __('Select a Category to show in latest news Section','eightmedi-pro'),
		'section' => 'eightmedi_pro_news_section',
		'setting' => 'eightmedi_pro_news_setting_category'
	)));

	//number of posts in news section
	$wp_customize->add_setting('eightmedi_pro_news_number', array(
		'default' => '6',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_number_posts',
	));

	$wp_customize->add_control('eightmedi_pro_news_number', array(
		'type' => 'select',
		'label' => __('Number of posts in News Section', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_news_section',
		'setting' => 'eightmedi_pro_news_number',
		'choices' => array(
			'3' => __('Three', 'eightmedi-pro'),
			'6' => __('Six', 'eightmedi-pro'),
			'9' => __('Nine', 'eightmedi-pro'),
			'12' => __('Twelve', 'eightmedi-pro'),
		)
	));

   //news button enable disable
	$wp_customize->add_setting('eightmedi_pro_news_button_option', array(
		'default' => 'disable',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_enabledisable',
	));

	$wp_customize->add_control('eightmedi_pro_news_button_option', array(
		'type' => 'radio',
		'label' => __('Display Button for Category Page', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_news_section',
		'setting' => 'eightmedi_pro_news_button_option',
		'choices' => array(
			'enable' => __('Enable', 'eightmedi-pro'),
			'disable' => __('Disable', 'eightmedi-pro'),
		)
	));

   //news Button View more text
	$wp_customize->add_setting('eightmedi_pro_news_button_text', array(
		'default' => 'View More',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
		'transport' => 'postMessage'
	));

	$wp_customize->add_control('eightmedi_pro_news_button_text',array(
		'type' => 'text',
		'label' => __('Button Text','eightmedi-pro'),
		'section' => 'eightmedi_pro_news_section',
		'setting' => 'eightmedi_pro_news_button_text'
	));

	$wp_customize->add_setting('eightmedi_pro_news_setting_date', array(
		'default' => 'enable',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_enabledisable',
	));

	$wp_customize->add_control('eightmedi_pro_news_setting_date', array(
		'type' => 'radio',
		'label' => __('Enable Disable News Date', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_news_section',
		'setting' => 'eightmedi_pro_news_setting_date',
		'choices' => array(
			'enable' => __('Enable', 'eightmedi-pro'),
			'disable' => __('Disable', 'eightmedi-pro'),
		)
	));

	//here goes testimonial section
	//testimonial Section
	$wp_customize->add_section('eightmedi_pro_testimonial_section', array(
		'priority' => 70,
		'title' => __('Our Testimonials', 'eightmedi-pro'),
		'description' => __('Testimonial Section posts will be loaded from post type Testimonial', 'eightmedi-pro'),
		'panel' => 'eightmedi_pro_homepage_setups',
	));

    //enable disable testimonial section
	$wp_customize->add_setting('eightmedi_pro_testimonial_setting_option', array(
		'default' => 'disable',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_enabledisable',
	));

	$wp_customize->add_control('eightmedi_pro_testimonial_setting_option', array(
		'type' => 'radio',
		'label' => __('Enable Disable testimonial Section', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_testimonial_section',
		'setting' => 'eightmedi_pro_testimonial_setting_option',
		'choices' => array(
			'enable' => __('Enable', 'eightmedi-pro'),
			'disable' => __('Disable', 'eightmedi-pro'),
		)
	));

   //testimonial Title
	$wp_customize->add_setting('eightmedi_pro_testimonial_title', array(
		'default' => 'Our Testimonial',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
	));

	$wp_customize->add_control('eightmedi_pro_testimonial_title',array(
		'type' => 'text',
		'label' => __('testimonial Section','eightmedi-pro'),
		'section' => 'eightmedi_pro_testimonial_section',
		'setting' => 'eightmedi_pro_testimonial_title'
	));

	$wp_customize->add_setting('eightmedi_pro_testimonial_shortcode', array(
		'default' => '',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
	));

	$wp_customize->add_control('eightmedi_pro_testimonial_shortcode',array(
		'type' => 'text',
		'label' => __('Other Plugin Shortcode for Testimonial','eightmedi-pro'),
		'description' => __('You can add shortcode of external plugins which provides testimonial functionality, if this field is empty default testimonials are fetched.','eightmedi-pro'),
		'section' => 'eightmedi_pro_testimonial_section',
	));

	$wp_customize->add_setting('eightmedi_pro_testimonial_bkgimage', array(
		'default' => '',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'esc_url_raw'
	));

	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'eightmedi_pro_testimonial_bkgimage', array(
		'label' => __('Image for Testimonial Background', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_testimonial_section',
		'setting' => 'eightmedi_pro_testimonial_bkgimage'
	)));

	//faqs Section
	$wp_customize->add_section('eightmedi_pro_faqs_section', array(
		'priority' => 70,
		'title' => __('FAQs Section', 'eightmedi-pro'),
		'description' => __('Faqs Section posts will be loaded from post type Faqs', 'eightmedi-pro'),
		'panel' => 'eightmedi_pro_homepage_setups',
	));

    //enable disable faqs section
	$wp_customize->add_setting('eightmedi_pro_faqs_setting_option', array(
		'default' => 'disable',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_enabledisable',
	));

	$wp_customize->add_control('eightmedi_pro_faqs_setting_option', array(
		'type' => 'radio',
		'label' => __('Enable Disable Faqs Section', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_faqs_section',
		'setting' => 'eightmedi_pro_faqs_setting_option',
		'choices' => array(
			'enable' => __('Enable', 'eightmedi-pro'),
			'disable' => __('Disable', 'eightmedi-pro'),
		)
	));

   //faqs Title
	$wp_customize->add_setting('eightmedi_pro_faqs_title', array(
		'default' => '',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
	));

	$wp_customize->add_control('eightmedi_pro_faqs_title',array(
		'type' => 'text',
		'label' => __('Faqs Title','eightmedi-pro'),
		'section' => 'eightmedi_pro_faqs_section',
		'setting' => 'eightmedi_pro_faqs_title'
	));

	//faqs number
	$wp_customize->add_setting('eightmedi_pro_faqs_number', array(
		'default' => '10',
		'sanitize_callback' => 'eightmedi_pro_sanitize_integer',
	));

	$wp_customize->add_control('eightmedi_pro_faqs_number',array(
		'type' => 'number',
		'label' => __('Faqs Number of Posts','eightmedi-pro'),
		'section' => 'eightmedi_pro_faqs_section',
		'setting' => 'eightmedi_pro_faqs_number'
	));

	//faqs read more
	$wp_customize->add_setting('eightmedi_pro_faqs_readmore', array(
		'default' => '',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
	));

	$wp_customize->add_control('eightmedi_pro_faqs_readmore',array(
		'type' => 'text',
		'label' => __('Faqs Read More Text','eightmedi-pro'),
		'section' => 'eightmedi_pro_faqs_section',
		'setting' => 'eightmedi_pro_faqs_readmore'
	));

	//faqs read more
	$wp_customize->add_setting('eightmedi_pro_faqs_status', array(
		'default' => 'expand',
		'sanitize_callback' => 'eightmedi_pro_sanitize_faqstatus',
	));

	$wp_customize->add_control('eightmedi_pro_faqs_status',array(
		'type' => 'radio',
		'label' => __('Faqs Status on Homepage','eightmedi-pro'),
		'section' => 'eightmedi_pro_faqs_section',
		'setting' => 'eightmedi_pro_faqs_readmore',
		'choices' => array(
			'expand' => __('Expanded','eightmedi-pro'),
			'collapse' => __('Collapsed','eightmedi-pro')
		)
	));

	$wp_customize->add_setting('eightmedi_pro_faqs_bkgimage', array(
		'default' => '',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'esc_url_raw'
	));

	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'eightmedi_pro_faqs_bkgimage', array(
		'label' => __('Image for Faqs Background', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_faqs_section',
		'setting' => 'eightmedi_pro_faqs_bkgimage'
	)));

	//here goes sponsors section
	//sponsors Section
	$wp_customize->add_section('eightmedi_pro_sponsors_section', array(
		'priority' => 70,
		'title' => __('Our Sponsors Section', 'eightmedi-pro'),
		'description' => __('Sponsors Section posts will be loaded from post type Sponsors', 'eightmedi-pro'),
		'panel' => 'eightmedi_pro_homepage_setups',
	));

    //enable disable sponsors section
	$wp_customize->add_setting('eightmedi_pro_sponsors_setting_option', array(
		'default' => 'disable',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_enabledisable',
	));

	$wp_customize->add_control('eightmedi_pro_sponsors_setting_option', array(
		'type' => 'radio',
		'label' => __('Enable Disable Sponsors Section', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_sponsors_section',
		'setting' => 'eightmedi_pro_sponsors_setting_option',
		'choices' => array(
			'enable' => __('Enable', 'eightmedi-pro'),
			'disable' => __('Disable', 'eightmedi-pro'),
		)
	));


   //sponsors Title
	$wp_customize->add_setting('eightmedi_pro_sponsors_title', array(
		'default' => 'Our Sponsors',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
	));

	$wp_customize->add_control('eightmedi_pro_sponsors_title',array(
		'type' => 'text',
		'label' => __('Sponsors Section','eightmedi-pro'),
		'section' => 'eightmedi_pro_sponsors_section',
		'setting' => 'eightmedi_pro_sponsors_title'
	));

	$wp_customize->add_setting('eightmedi_pro_sponsors_layout', array(
		'default' => 'sliding',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_sponsor',
	));

	$wp_customize->add_control('eightmedi_pro_sponsors_layout', array(
		'type' => 'radio',
		'label' => __('Sponsors Layout', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_sponsors_section',
		'setting' => 'eightmedi_pro_sponsors_layout',
		'choices' => array(
			'sliding' => __('Slider', 'eightmedi-pro'),
			'static' => __('Static List', 'eightmedi-pro'),
		)
	));

	//Small Call To Action Section

	$wp_customize->add_section('eightmedi_pro_callto_small_section', array(
		'priority' => 140,
		'title' => __('Small Call To Action Section', 'eightmedi-pro'),
		'panel' => 'eightmedi_pro_homepage_setups',
	));

    //enable disable call to action section
	$wp_customize->add_setting('eightmedi_pro_callto_small_setting_option', array(
		'default' => 'disable',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'eightmedi_pro_radio_sanitize_enabledisable',
	));

	$wp_customize->add_control('eightmedi_pro_callto_small_setting_option', array(
		'type' => 'radio',
		'label' => __('Enable Disable Small Call To Action', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_callto_small_section',
		'setting' => 'eightmedi_pro_callto_small_setting_option',
		'choices' => array(
			'enable' => __('Enable', 'eightmedi-pro'),
			'disable' => __('Disable', 'eightmedi-pro'),
		)
	));


   //call to action Title
	$wp_customize->add_setting('eightmedi_pro_callto_small_title', array(
		'default' => 'Make Your Appointment Today',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
	));

	$wp_customize->add_control('eightmedi_pro_callto_small_title',array(
		'type' => 'text',
		'label' => __('Small Call To Action Title','eightmedi-pro'),
		'section' => 'eightmedi_pro_callto_small_section',
		'setting' => 'eightmedi_pro_callto_small_title'
	));

    //call to action read more
	$wp_customize->add_setting('eightmedi_pro_callto_readmore_small', array(
		'default' => 'Book Now',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',
		'transport' => 'postMessage'
	));

	$wp_customize->add_control('eightmedi_pro_callto_readmore_small',array(
		'type' => 'text',
		'label' => __('Small Call To Action Read More Text','eightmedi-pro'),
		'section' => 'eightmedi_pro_callto_small_section',
		'setting' => 'eightmedi_pro_callto_readmore_small'
	));

   //call to action link
	$wp_customize->add_setting('eightmedi_pro_callto_link_small', array(
		'default' => '',
		'sanitize_callback' => 'eightmedi_pro_sanitize_text',

	));

	$wp_customize->add_control('eightmedi_pro_callto_link_small',array(
		'type' => 'text',
		'label' => __('Call To Action Link','eightmedi-pro'),
		'section' => 'eightmedi_pro_callto_small_section',
		'setting' => 'eightmedi_pro_callto_link_small'
	));
   //call to action background image
	$wp_customize->add_setting('eightmedi_pro_callto_bkgimage_small', array(
		'default' => '',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'esc_url_raw'
	));

	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'eightmedi_pro_callto_bkgimage_small', array(
		'label' => __('Image for Small Call to Action', 'eightmedi-pro'),
		'section' => 'eightmedi_pro_callto_small_section',
		'setting' => 'eightmedi_pro_callto_bkgimage_small'
	)));

	//Google Map Section
	$wp_customize->add_section('eightmedi_pro_google_map_section',array(
		'title' => __( 'Google Map', 'eightmedi-pro' ),
		'priority' => 140,
		'panel' => 'eightmedi_pro_homepage_setups',
	));

	// $wp_customize->add_setting('eightmedi_pro_google_map_iframe',array(
	// 	'default' => '',
	// 	'sanitize_callback' => 'wp_kses_stripslashes',
	// 	));

	// $wp_customize->add_control( 'eightmedi_pro_google_map_iframe',array(
	// 	'label' => __( 'Google Map Iframe', 'eightmedi-pro' ),
	// 	'section' => 'eightmedi_pro_google_map_section',
	// 	'description' => __( "Enter the Google Map Iframe", 'eightmedi-pro' ),
	// 	'type' => 'textarea',
	// 	));

	$wp_customize->add_setting('eightmedi_pro_contact_address',array(
		'default' => '',
		'sanitize_callback' => 'wp_kses_post',
	));

	$wp_customize->add_control( 'eightmedi_pro_contact_address',array(
		'label' => __( 'Contact Address', 'eightmedi-pro' ),
		'section' => 'eightmedi_pro_google_map_section',
		'description' => __( "Enter the Contact Address Detail, add google map from widgets section", 'eightmedi-pro' ),
		'type' => 'textarea',
	));


	//end of Homepage section
}
add_action( 'customize_register', 'eightmedi_pro_custom_customize_register_homepage' );